@@ -17,7 +17,7 @@ use Carp;
 use vars qw($VERSION @ISA @EXPORT $AUTOLOAD
 		$use_XSLoader);
 
-$VERSION = '0.23';
+$VERSION = '0.24';
 
 require Exporter;
 #require DynaLoader;
@@ -50,6 +50,7 @@ BEGIN {
 	DB_ARCH_ABS
 	DB_ARCH_DATA
 	DB_ARCH_LOG
+	DB_ARCH_REMOVE
 	DB_AUTO_COMMIT
 	DB_BEFORE
 	DB_BROADCAST_EID
@@ -60,6 +61,7 @@ BEGIN {
 	DB_CACHED_COUNTS
 	DB_CDB_ALLDB
 	DB_CHECKPOINT
+	DB_CHKSUM
 	DB_CHKSUM_SHA1
 	DB_CLIENT
 	DB_CL_WRITER
@@ -96,6 +98,7 @@ BEGIN {
 	DB_ENV_LOCKDOWN
 	DB_ENV_LOCKING
 	DB_ENV_LOGGING
+	DB_ENV_LOG_AUTOREMOVE
 	DB_ENV_NOLOCKING
 	DB_ENV_NOMMAP
 	DB_ENV_NOPANIC
@@ -112,8 +115,10 @@ BEGIN {
 	DB_ENV_STANDALONE
 	DB_ENV_SYSTEM_MEM
 	DB_ENV_THREAD
+	DB_ENV_TIME_NOTGRANTED
 	DB_ENV_TXN
 	DB_ENV_TXN_NOSYNC
+	DB_ENV_TXN_NOT_DURABLE
 	DB_ENV_TXN_WRITE_NOSYNC
 	DB_ENV_USER_ALLOC
 	DB_ENV_YIELDCPU
@@ -121,6 +126,7 @@ BEGIN {
 	DB_EXTENT
 	DB_FAST_STAT
 	DB_FCNTL_LOCKING
+	DB_FILEOPEN
 	DB_FILE_ID_LEN
 	DB_FIRST
 	DB_FIXEDLEN
@@ -141,6 +147,7 @@ BEGIN {
 	DB_INIT_LOCK
 	DB_INIT_LOG
 	DB_INIT_MPOOL
+	DB_INIT_REP
 	DB_INIT_TXN
 	DB_INVALID_EID
 	DB_JAVA_CALLBACK
@@ -194,9 +201,16 @@ BEGIN {
 	DB_LOGMAGIC
 	DB_LOGOLDVER
 	DB_LOGVERSION
+	DB_LOG_AUTOREMOVE
+	DB_LOG_CHKPNT
+	DB_LOG_COMMIT
 	DB_LOG_DISK
 	DB_LOG_LOCKED
+	DB_LOG_NOCOPY
+	DB_LOG_NOT_DURABLE
+	DB_LOG_PERM
 	DB_LOG_SILENT_ERR
+	DB_LOG_WRNOSYNC
 	DB_MAX_PAGES
 	DB_MAX_RECORDS
 	DB_MPOOL_CLEAN
@@ -207,7 +221,9 @@ BEGIN {
 	DB_MPOOL_LAST
 	DB_MPOOL_NEW
 	DB_MPOOL_NEW_GROUP
+	DB_MPOOL_NOFILE
 	DB_MPOOL_PRIVATE
+	DB_MPOOL_UNLINK
 	DB_MULTIPLE
 	DB_MULTIPLE_KEY
 	DB_MUTEXDEBUG
@@ -229,6 +245,7 @@ BEGIN {
 	DB_NOSERVER_ID
 	DB_NOSYNC
 	DB_NOTFOUND
+	DB_NO_AUTO_COMMIT
 	DB_ODDFILESIZE
 	DB_OK_BTREE
 	DB_OK_HASH
@@ -279,17 +296,23 @@ BEGIN {
 	DB_RENAMEMAGIC
 	DB_RENUMBER
 	DB_REP_CLIENT
+	DB_REP_CREATE
 	DB_REP_DUPMASTER
+	DB_REP_HANDLE_DEAD
 	DB_REP_HOLDELECTION
+	DB_REP_ISPERM
 	DB_REP_LOGSONLY
 	DB_REP_MASTER
 	DB_REP_NEWMASTER
 	DB_REP_NEWSITE
+	DB_REP_NOBUFFER
+	DB_REP_NOTPERM
 	DB_REP_OUTDATED
 	DB_REP_PERMANENT
 	DB_REP_UNAVAIL
 	DB_REVSPLITOFF
 	DB_RMW
+	DB_RPCCLIENT
 	DB_RPC_SERVERPROG
 	DB_RPC_SERVERVERS
 	DB_RUNRECOVERY
@@ -332,6 +355,7 @@ BEGIN {
 	DB_TEST_SUBDB_LOCKS
 	DB_THREAD
 	DB_TIMEOUT
+	DB_TIME_NOTGRANTED
 	DB_TRUNCATE
 	DB_TXNMAGIC
 	DB_TXNVERSION
@@ -352,6 +376,7 @@ BEGIN {
 	DB_TXN_LOG_UNDO
 	DB_TXN_LOG_UNDOREDO
 	DB_TXN_NOSYNC
+	DB_TXN_NOT_DURABLE
 	DB_TXN_NOWAIT
 	DB_TXN_OPENFILES
 	DB_TXN_POPENFILES
@@ -386,6 +411,8 @@ BEGIN {
 	DB_XA_CREATE
 	DB_XIDDATASIZE
 	DB_YIELDCPU
+	DB_debug_FLAG
+	DB_user_BEGIN
 	);
 
 sub AUTOLOAD {
@@ -1539,6 +1566,7 @@ sub DESTROY
     $self->_DESTROY() ;
 }
 
+
 package BerkeleyDB::Term ;
 
 END
